import Vue from 'vue'

const state = {
  subject: JSON.parse(localStorage.getItem('subject')) || [],
  object: JSON.parse(localStorage.getItem('object')) || [],
  relationship: JSON.parse(localStorage.getItem('relationship')) || [],
  colors: ['#6bc9ed', '#009ce0', '#0062b1', '#aea1ff', '#7b64ff', '#653294', '#fda1ff', '#fa28ff', '#68ccca', '#16a5a5', '#0c797d', '#a4dd00', '#68bc00', '#194d33', '#fcdc00', '#fcc400', '#fb9e00', '#f44e3b', '#d33115', '#9f0500']
}

const mutations = {
  // 写入state
  loadSubject(state, subjectData) {
    state.subject = subjectData
  },
  loadObject(state, objectData) {
    state.object = objectData
  },
  loadRelationship(state, relationshipData) {
    state.relationship = relationshipData
  },
  // 添加新项
  ADD_SUBJECT(state, newItem) {
    state.subject.push(newItem)
    localStorage.setItem('subject', JSON.stringify(state.subject))
  },
  ADD_OBJECT(state, newItem) {
    state.object.push(newItem)
    localStorage.setItem('object', JSON.stringify(state.object))
  },
  ADD_RELATIONSHIP(state, newItem) {
    state.relationship.push(newItem)
    localStorage.setItem('relationship', JSON.stringify(state.relationship))
  },
  // 更新项
  UPDATE_SUBJECT(state, updatedItem) {
    const index = state.subject.findIndex(item => item.id === updatedItem.id)
    if (index !== -1) {
      state.subject[index] = updatedItem
      localStorage.setItem('subject', JSON.stringify(state.subject))
      Vue.prototype.$message({
        message: '修改成功',
        type: 'success'
      })
    } else {
      Vue.prototype.$message({
        message: '未找到该条数据',
        type: 'success'
      })
    }
  },
  UPDATE_OBJECT(state, updatedItem) {
    const index = state.object.findIndex(item => item.id === updatedItem.id)
    if (index !== -1) {
      state.object[index] = updatedItem
      localStorage.setItem('object', JSON.stringify(state.object))
    }
  },
  UPDATE_RELATIONSHIP(state, updatedItem) {
    const index = state.relationship.findIndex(item => item.id === updatedItem.id)
    if (index !== -1) {
      state.relationship[index] = updatedItem
      localStorage.setItem('relationship', JSON.stringify(state.relationship))
    }
  },
  // 删除项
  DEL_SUBJECT(state, itemId) {
    state.subject = state.subject.filter(item => item.id !== itemId)
  },
  DEL_OBJECT(state, itemId) {
    state.object = state.object.filter(item => item.id !== itemId)
  },
  DEL_RELATIONSHIP(state, itemId) {
    state.relationship = state.relationship.filter(item => item.id !== itemId)
  }
}
const actions = {
  // 添加新项的 action
  addSubject({ commit }, newItem) {
    commit('ADD_SUBJECT', newItem)
  },
  addObject({ commit }, newItem) {
    commit('ADD_OBJECT', newItem)
  },
  addRelationship({ commit }, newItem) {
    commit('ADD_RELATIONSHIP', newItem)
  },
  // 更新项的 action
  updateSubject({ commit }, updatedItem) {
    commit('UPDATE_SUBJECT', updatedItem)
  },
  updateObject({ commit }, updatedItem) {
    commit('UPDATE_OBJECT', updatedItem)
  },
  updateRelationship({ commit }, updatedItem) {
    commit('UPDATE_RELATIONSHIP', updatedItem)
  },
  // 删除项的 action
  delSubject({ commit }, itemId) {
    commit('DEL_SUBJECT', itemId)
  },
  delObject({ commit }, itemId) {
    commit('DEL_OBJECT', itemId)
  },
  delRelationship({ commit }, itemId) {
    commit('DEL_RELATIONSHIP', itemId)
  }
}
export default {
  namespaced: true,
  state,
  mutations,
  actions
}
